module.exports = "import * as React from 'react';\n\nexport interface IChoiceGroupProps extends React.HTMLProps<HTMLElement> {\n  /**\n   * The options for the choice group.\n   */\n  options: IChoiceGroupOption[];\n\n  /**\n   * A callback for receiving a notification when the choice has been changed.\n   */\n  onChanged?: (option: IChoiceGroupOption, evt?: React.FormEvent<HTMLInputElement>) => void;\n\n  /**\n   * Descriptive label for the choice group.\n   */\n  label?: string;\n}\n\nexport interface IChoiceGroupOption {\n  /**\n   * A required key to uniquely identify the option.\n   */\n  key: string;\n\n  /**\n   * The text string for the option.\n   */\n  text: string;\n\n  /**\n   * The src of image for choice field.\n   */\n  imageSrc?: string;\n\n  /**\n   * The src of image for choice field which is selected.\n   */\n  selectedImageSrc?: string;\n\n  /**\n   * The width and height of the image in px for choice field.\n   */\n  imageSize?: { width: number, height: number };\n\n  /**\n   * Whether or not this menu item is currently checked.\n   * @defaultvalue false\n   */\n  checked?: boolean;\n\n  /**\n   * @deprecated\n   * Deprecated at v.65.1 and will be removed by v 1.0. Use 'checked' instead.\n   */\n  isChecked?: boolean;\n\n  /**\n   * Whether or not the option is disabled.\n   */\n  disabled?: boolean;\n\n  // @todo: Update version numbers for depriate and removal\n  /**\n   * @deprecated\n   * Deprecated at v0.52.0, to be removed at >= v1.0.0. Use 'disabled' instead.\n   */\n  isDisabled?: boolean;\n}\n";